Publishing
==========

The ``publish`` module
----------------------

.. module:: bookstore.publish

``BookstorePublishAPIHandler``
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: BookstorePublishAPIHandler

Methods
^^^^^^^

.. automethod:: BookstorePublishAPIHandler.initialize

.. automethod:: BookstorePublishAPIHandler.put

.. automethod:: BookstorePublishAPIHandler.validate_model

.. automethod:: BookstorePublishAPIHandler.prepare_response
